@@ -110,7 +110,7 @@ class RecordLoader:
         signal = self.getSignal(recordName)
         eventList = self.getEventList(recordName, targetFrequency=eventTargetFrequency)
 
-        NormalizeRecordSignal().combine(signal, self.combineChannels)
+        NormalizeRecordSignal().combine(signal, self.combineChannels, self.targetSignals)
 
         return signal, eventList
 
