@@ -39,4 +39,9 @@ class S3Downloader(Downloader):
                     percentage = downloadedBytes / fileSize * 100
                     downloadList.set_postfix({"current file": "{:.1f}%".format(percentage)})
 
-            client.download_file(Bucket=self.bucket, Key=filename, Filename=filePath + "/{}".format(filename), Callback=update)
+            client.download_file(
+                Bucket=self.bucket,
+                Key=filename,
+                Filename=filePath + "/{}".format(filename),
+                Callback=update,
+            )
