@@ -116,51 +116,6 @@ class EDFRecordLoader(RecordLoader):
             "patientAdd": f.getPatientAdditional(),
             "start": f.getStartdatetime(),
             "technician": f.getTechnician(),
+            "dataCount": f.datarecords_in_file,
         }
 
-    # def fillRecordFromEdf(self, record, edfFile):
-    #     edf = pyedflib.EdfReader(edfFile)
-    #     signalHeaders = edf.getSignalHeaders()
-
-    #     record.dataCount = edf.datarecords_in_file
-    #     record.start = edf.getStartdatetime()
-
-    #     for i in range(len(signalHeaders)):
-    #         head = signalHeaders[i]
-    #         channel = Channel()
-    #         recordChannel = RecordChannel()
-
-    #         channel.name = head["label"]
-    #         channel.dimension = head["dimension"]
-    #         channel.min = head["physical_min"]
-    #         channel.max = head["physical_max"]
-    #         recordChannel.transducer = head["transducer"]
-    #         recordChannel.frequency = head["sample_rate"]
-    #         recordChannel.prefilter = head["prefilter"]
-
-    #         signalArray = edf.readSignal(i)
-    #         signal = Signal(channel.name, signalArray, frequency=recordChannel.frequency)
-    #         signal.dimension = channel.dimension
-    #         signal.typeStr = self.getSignalTypeStrFromDict(signal.name)
-    #         signal.checkSignalQuality()
-    #         recordChannel.quality = signal.quality
-
-    #         recordChannel.Channel = channel
-    #         record.recordChannels.append(recordChannel)
-
-    #     patient = Patient()
-    #     header = edf.getHeader()
-    #     patient.gender = header["gender"]
-    #     try:
-    #         birthday = datetime.strptime(header["birthdate"], "%d %b %Y")
-    #         patient.birthyear = birthday.year
-    #     except Exception:
-    #         pass
-
-    #     record.Patient = patient
-
-    # def getRecordFromEdf(self, recordName) -> Record:
-    #     record = Record()
-    #     edfFile = self.getFilePathSignal(recordName)
-    #     self.fillRecordFromEdf(record, edfFile)
-    #     return record
